/*
 * System Interface Library for games
 * Copyright (c) 2007-2014 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * sample/sample.c: Sample client source file for SIL.
 */

/*
 * This file implements a simple client of the SIL library which serves
 * two purposes: it demonstrates how a program can use the SIL build system
 * to build an executable, and it allows the internal SIL tests to be run
 * with a "-test" command-line parameter.
 *
 * See the Makefile in the build/ subdirectory of this directory for
 * details on how to use the SIL build system.
 */

#include <SIL/base.h>
#include <SIL/test.h>

/* When testing, include all other headers to check for public header bugs. */
#ifdef INCLUDE_TESTS
# include <SIL/debug.h>
# include <SIL/endian.h>
# include <SIL/font.h>
# include <SIL/graphics.h>
# include <SIL/input.h>
# include <SIL/keycodes.h>
# include <SIL/math.h>
# include <SIL/memory.h>
# include <SIL/movie.h>
# include <SIL/mutex.h>
# include <SIL/random.h>
# include <SIL/resource.h>
# include <SIL/resource/package.h>
# include <SIL/semaphore.h>
# include <SIL/sound.h>
# include <SIL/sound/decode.h>
# ifdef SIL_PLATFORM_IOS
#  include <SIL/sysdep/ios/gamekit.h>
# endif
# include <SIL/texture.h>
# include <SIL/thread.h>
# include <SIL/time.h>
# include <SIL/userdata.h>
# include <SIL/utility/compress.h>
# include <SIL/utility/misc.h>
# include <SIL/utility/strformat.h>
# include <SIL/utility/utf8.h>
# include <SIL/workqueue.h>
#endif  // INCLUDE_TESTS

int sil_main(int argc, const char **argv)
{
    if (argc > 1 && (strcmp(argv[1], "-test") == 0
                     || strncmp(argv[1], "-test=", 6) == 0)) {
        const char *tests_to_run = (strlen(argv[1]) > 6) ? &argv[1][6] : "";
        if (!run_internal_tests(tests_to_run)) {
            return EXIT_FAILURE;
        }
    }

    DLOG("%s says: Hello, world!", *argv[0] ? argv[0] : "No Name");
    return EXIT_SUCCESS;
}
